bettermap
=========

`bettermap` is a drop-in replacement for Python's map function. It parallelizes
the map function across all available processors.

Install with `pip install https://github.com/allenai/bettermap/releases/download/v1.3.0/bettermap-1.3.0-py3-none-any.whl`
